@@ -263,6 +263,7 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertNotEqual(apple_pay_card.debit, None)
         self.assertNotEqual(apple_pay_card.durbin_regulated, None)
         self.assertNotEqual(apple_pay_card.healthcare, None)
+        self.assertTrue(apple_pay_card.is_device_token)
         self.assertNotEqual(apple_pay_card.issuing_bank, None)
         self.assertNotEqual(apple_pay_card.last_4, None)
         self.assertNotEqual(apple_pay_card.payroll, None)
@@ -302,6 +303,7 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertNotEqual(apple_pay_card.debit, None)
         self.assertNotEqual(apple_pay_card.durbin_regulated, None)
         self.assertNotEqual(apple_pay_card.healthcare, None)
+        self.assertFalse(apple_pay_card.is_device_token)
         self.assertNotEqual(apple_pay_card.issuing_bank, None)
         self.assertNotEqual(apple_pay_card.last_4, None)
         self.assertNotEqual(apple_pay_card.merchant_token_identifier, None)
@@ -364,11 +366,11 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertNotEqual(android_pay_card.token, None)
         self.assertEqual(customer_id, android_pay_card.customer_id)
         self.assertEqual(CreditCard.CardType.MasterCard, android_pay_card.virtual_card_type)
-        self.assertEqual("4444", android_pay_card.virtual_card_last_4)
-        self.assertEqual("MasterCard 4444", android_pay_card.source_description)
+        self.assertEqual("0005", android_pay_card.virtual_card_last_4)
+        self.assertEqual("MasterCard 0005", android_pay_card.source_description)
         self.assertEqual(CreditCard.CardType.MasterCard, android_pay_card.source_card_type)
-        self.assertEqual("4444", android_pay_card.source_card_last_4)
-        self.assertEqual("4444", android_pay_card.last_4)
+        self.assertEqual("0005", android_pay_card.source_card_last_4)
+        self.assertEqual("0005", android_pay_card.last_4)
         self.assertEqual(CreditCard.CardType.MasterCard, android_pay_card.card_type)
         self.assertTrue(android_pay_card.default)
         self.assertIn("android_pay", android_pay_card.image_url)
